@@ -99,7 +99,7 @@ def seven_cloudapp_ppmt_route():
         (r"/server/checking_price_gear", machine_s.CheckingPriceGearHandler),  #验证价格档位
         # 2.2
         (r"/server/give_prop_list", user_s.PropGiveListHandler),
-        (r"/server/shop_power_config", power_s.ShopPowerConfigHandler),
+        (r"/server/get_high_power_list", power_s.ShopPowerConfigHandler),
         #2.4
         (r"/server/check_gm_power", app_s.CheckGmPowerHandler),  #获取是否有GM工具权限 用于GM工具
         (r"/server/get_appid_by_gm", app_s.GetAppidByGmHandler),  #根据店铺名称返回应用标识 用于GM工具
@@ -159,5 +159,5 @@ def seven_cloudapp_ppmt_route():
         #2.4
         (r"/client/get_crm_integral", user.GetCrmIntegralHandler),
         (r"/client/crm_integral_gear_list", act.CrmIntegralGearlListHandler),
-        (r"/client/shop_power_config", power.ShopPowerConfigHandler),
+        (r"/client/get_high_power_list", power.ShopPowerConfigHandler),
     ]
\ No newline at end of file
